<p align="center">
  <picture>
    <source media="(prefers-color-scheme: dark)" srcset="https://github.com/Saplinging/dufteplots/blob/main/docs/images/Logo_dufteplots_SchwarzerHintergrund.png?raw=true">
    <img src="https://github.com/Saplinging/dufteplots/blob/main/docs/images/Logo_dufteplots_Wei%C3%9FerHintergrund.png?raw=true" alt="dufteplots Logo">
  </picture>
  <br>
  <em>"Above all else show the data." – Edward Tufte (1983)</em>
</p>

-----------------

# dufteplots: Tufte-style Data Visualization for Python

|  |  |
| --- | --- |
| **Testing** | [![Tests](https://github.com/Saplinging/dufteplots/actions/workflows/tests.yml/badge.svg)](https://github.com/Saplinging/dufteplots/actions/workflows/tests.yml) |
| **Package** | [![PyPI Latest Release](https://img.shields.io/pypi/v/dufteplots.svg)](https://pypi.org/project/dufteplots/) [![PyPI Downloads](https://img.shields.io/pypi/dm/dufteplots.svg?label=PyPI%20downloads)](https://pypi.org/project/dufteplots/) |
| **Meta** | [![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT) [![Code Style: Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black) [![Python Versions](https://img.shields.io/pypi/pyversions/dufteplots.svg)](https://pypi.org/project/dufteplots/) |


## Plots

- **Range-Frame Plot**: Minimale Boxplot-Alternative zur Darstellung von Datenspannen
- **Dot-Dash Plot**: Streudiagramme mit integrierten Randverteilungen
- **Slopegraph**: Vergleich von Veränderungen zwischen zwei Zeitpunkten
- **Small Multiples**: Facettierte Darstellungen für Mustervergleiche
- **Sparklines**: Kompakte Inline-Zeitreihen
- **Layered Focus**: Hervorhebung spezifischer Daten im Kontext
- **Time Series**: Klare zeitliche Visualisierungen


## Installation & Verwendung

```bash
pip install dufteplots
```

```python
import dufteplots as dp
```